@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2025 Intel Corporation
+ * Copyright (C) 2020-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,10 +16,12 @@
 #include <string>
 #include <sys/file.h>
 #include <sys/ioctl.h>
+#include <sys/socket.h>
 #include <sys/stat.h>
 #include <sys/syscall.h>
 #include <sys/sysmacros.h>
 #include <sys/types.h>
+#include <sys/un.h>
 #include <unistd.h>
 
 #ifndef SYS_pidfd_open
@@ -65,6 +67,10 @@ int mkdir(const std::string &path) {
     return ::mkdir(path.c_str(), S_IRWXU | S_IRWXG | S_IROTH | S_IXOTH);
 }
 
+int rmdir(const std::string &path) {
+    return ::rmdir(path.c_str());
+}
+
 int close(int fd) {
     return ::close(fd);
 }
@@ -221,5 +227,54 @@ long sysconf(int name) {
 int mkfifo(const char *pathname, mode_t mode) {
     return ::mkfifo(pathname, mode);
 }
+
+int socket(int domain, int type, int protocol) {
+    return ::socket(domain, type, protocol);
+}
+
+int bind(int sockfd, const struct sockaddr *addr, socklen_t addrlen) {
+    return ::bind(sockfd, addr, addrlen);
+}
+
+int listen(int sockfd, int backlog) {
+    return ::listen(sockfd, backlog);
+}
+
+int accept(int sockfd, struct sockaddr *addr, socklen_t *addrlen) {
+    return ::accept(sockfd, addr, addrlen);
+}
+
+int connect(int sockfd, const struct sockaddr *addr, socklen_t addrlen) {
+    return ::connect(sockfd, addr, addrlen);
+}
+
+ssize_t send(int sockfd, const void *buf, size_t len, int flags) {
+    return ::send(sockfd, buf, len, flags);
+}
+
+ssize_t recv(int sockfd, void *buf, size_t len, int flags) {
+    return ::recv(sockfd, buf, len, flags);
+}
+
+ssize_t sendmsg(int sockfd, const struct msghdr *msg, int flags) {
+    return ::sendmsg(sockfd, msg, flags);
+}
+
+ssize_t recvmsg(int sockfd, struct msghdr *msg, int flags) {
+    return ::recvmsg(sockfd, msg, flags);
+}
+
+int setsockopt(int sockfd, int level, int optname, const void *optval, socklen_t optlen) {
+    return ::setsockopt(sockfd, level, optname, optval, optlen);
+}
+
+int dup(int oldfd) {
+    return ::dup(oldfd);
+}
+
+pid_t getpid() {
+    return ::getpid();
+}
+
 } // namespace SysCalls
 } // namespace NEO
