@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2025 Intel Corporation
+ * Copyright (C) 2025-2026 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,7 @@
 using Family = NEO::Xe3CoreFamily;
 
 #include "shared/source/command_stream/command_stream_receiver_hw_dg2_and_later.inl"
+#include "shared/source/command_stream/command_stream_receiver_hw_from_xe_hpc_to_xe3.inl"
 #include "shared/source/command_stream/command_stream_receiver_hw_heap_addressing.inl"
 #include "shared/source/command_stream/command_stream_receiver_hw_xehp_and_later.inl"
 #include "shared/source/gmm_helper/gmm.h"
@@ -38,26 +39,6 @@ void populateFactoryTable<CommandStreamReceiverHw<Family>>() {
     commandStreamReceiverFactory[gfxCore] = DeviceCommandStreamReceiver<Family>::create;
 }
 
-template <>
-void CommandStreamReceiverHw<Family>::programEnginePrologue(LinearStream &csr) {
-    if (!this->isEnginePrologueSent) {
-        if (getGlobalFenceAllocation()) {
-            EncodeMemoryFence<Family>::encodeSystemMemoryFence(csr, getGlobalFenceAllocation());
-        }
-        this->isEnginePrologueSent = true;
-    }
-}
-
-template <>
-size_t CommandStreamReceiverHw<Family>::getCmdSizeForPrologue() const {
-    if (!this->isEnginePrologueSent) {
-        if (getGlobalFenceAllocation()) {
-            return EncodeMemoryFence<Family>::getSystemMemoryFenceSize();
-        }
-    }
-    return 0u;
-}
-
 template <>
 void BlitCommandsHelper<Family>::appendBlitCommandsBlockCopy(const BlitProperties &blitProperties, typename Family::XY_BLOCK_COPY_BLT &blitCmd, const RootDeviceEnvironment &rootDeviceEnvironment) {
     using XY_BLOCK_COPY_BLT = typename Family::XY_BLOCK_COPY_BLT;
